( cd usr/lib ; rm -rf gcrt0.o )
( cd usr/lib ; ln -sf /cdrom/live/usr/lib/gcrt0.o gcrt0.o )
( cd usr/lib ; rm -rf libc_p.a )
( cd usr/lib ; ln -sf /cdrom/live/usr/lib/libc_p.a libc_p.a )
( cd usr/lib ; rm -rf libgmon.a )
( cd usr/lib ; ln -sf /cdrom/live/usr/lib/libgmon.a libgmon.a )
( cd usr/lib ; rm -rf libmcheck.a )
( cd usr/lib ; ln -sf /cdrom/live/usr/lib/libmcheck.a libmcheck.a )
( cd usr/lib ; rm -rf libg.a )
( cd usr/lib ; ln -sf /cdrom/live/usr/lib/libg.a libg.a )
